@@ -32,7 +32,6 @@ import logging
 import logging.config
 import logging.handlers
 import os
-import platform
 import sys
 try:
     import syslog
@@ -40,6 +39,7 @@ except ImportError:
     syslog = None
 
 from oslo_config import cfg
+from oslo_utils import eventletutils
 from oslo_utils import importutils
 from oslo_utils import units
 
@@ -69,6 +69,8 @@ LOG_ROTATE_INTERVAL_MAPPING = {
     'midnight': 'midnight'
 }
 
+_EVENTLET_FIX_APPLIED = False
+
 
 def _get_log_file_path(conf, binary=None):
     logfile = conf.log_file
@@ -82,7 +84,7 @@ def _get_log_file_path(conf, binary=None):
 
     if logdir:
         binary = binary or handlers._get_binary_name()
-        return '%s.log' % (os.path.join(logdir, binary),)
+        return '{}.log'.format(os.path.join(logdir, binary))
 
     return None
 
@@ -231,7 +233,7 @@ def _load_log_config(log_config_append):
             logging.config.fileConfig(log_config_append,
                                       disable_existing_loggers=False)
             _load_log_config.old_time = new_time
-    except (configparser.Error, KeyError, os.error) as exc:
+    except (configparser.Error, KeyError, OSError, RuntimeError) as exc:
         raise LogConfigError(log_config_append, str(exc))
 
 
@@ -271,14 +273,16 @@ def _fix_eventlet_logging():
     Workaround for: https://github.com/eventlet/eventlet/issues/432
     """
 
+    global _EVENTLET_FIX_APPLIED
+
     # If eventlet was not loaded before call to setup assume it's not used.
-    eventlet = sys.modules.get('eventlet')
-    if eventlet:
+    if eventletutils.is_monkey_patched('thread') and not _EVENTLET_FIX_APPLIED:
         import eventlet.green.threading
         from oslo_log import pipe_mutex
         logging.threading = eventlet.green.threading
         logging._lock = logging.threading.RLock()
         logging.Handler.createLock = pipe_mutex.pipe_createLock
+        _EVENTLET_FIX_APPLIED = True
 
 
 def setup(conf, product_name, version='unknown', *, fix_eventlet=True):
@@ -372,10 +376,9 @@ def _setup_logging_from_conf(conf, project, version):
     logpath = _get_log_file_path(conf)
     if logpath:
         # On Windows, in-use files cannot be moved or deleted.
-        if conf.watch_log_file and platform.system() == 'Linux':
-            from oslo_log import watchers
-            file_handler = watchers.FastWatchedFileHandler
-            filelog = file_handler(logpath)
+        if conf.watch_log_file:
+            raise RuntimeError('watch_log_file feature was removed because '
+                               'it has been broken for multiple releases.')
         elif conf.log_rotation_type.lower() == "interval":
             file_handler = logging.handlers.TimedRotatingFileHandler
             when = conf.log_rotate_interval_type.lower()
@@ -401,7 +404,10 @@ def _setup_logging_from_conf(conf, project, version):
         log_root.addHandler(filelog)
 
     if conf.use_stderr:
-        streamlog = handlers.ColorHandler()
+        if conf.log_color:
+            streamlog = handlers.ColorHandler()
+        else:
+            streamlog = logging.StreamHandler()
         log_root.addHandler(streamlog)
 
     if conf.use_journal:
@@ -411,19 +417,12 @@ def _setup_logging_from_conf(conf, project, version):
         journal = handlers.OSJournalHandler(facility=facility)
         log_root.addHandler(journal)
 
-    if conf.use_eventlog:
-        if platform.system() == 'Windows':
-            eventlog = logging.handlers.NTEventLogHandler(project)
-            log_root.addHandler(eventlog)
-        else:
-            raise RuntimeError(_("Windows Event Log is not available on this "
-                                 "platform."))
-
     # if None of the above are True, then fall back to standard out
     if not logpath and not conf.use_stderr and not conf.use_journal:
-        # pass sys.stdout as a positional argument
-        # python2.6 calls the argument strm, in 2.7 it's stream
-        streamlog = handlers.ColorHandler(sys.stdout)
+        if conf.log_color:
+            streamlog = handlers.ColorHandler(sys.stdout)
+        else:
+            streamlog = logging.StreamHandler(sys.stdout)
         log_root.addHandler(streamlog)
 
     if conf.publish_errors:
@@ -472,7 +471,7 @@ def _setup_logging_from_conf(conf, project, version):
         from oslo_log import rate_limit
         rate_limit.install_filter(conf.rate_limit_burst,
                                   conf.rate_limit_interval,
-                                  conf.rate_limit_except)
+                                  conf.rate_limit_except_level)
 
 
 _loggers = {}
