@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2011 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -22,7 +20,6 @@ import datetime
 import io
 import logging
 import os
-import platform
 import shutil
 import sys
 try:
@@ -72,7 +69,7 @@ def _fake_context():
     ctxt = context.RequestContext(user_id="myuser",
                                   user_name="myuser",
                                   system_scope="myscope",
-                                  domain="mydomain",
+                                  domain_id="mydomain",
                                   project_id="mytenant",
                                   project_name="mytenant",
                                   project_domain_id="mydomain",
@@ -82,13 +79,13 @@ def _fake_context():
     return ctxt
 
 
-class CommonLoggerTestsMixIn(object):
+class CommonLoggerTestsMixIn:
     """These tests are shared between LoggerTestCase and
     LazyLoggerTestCase.
     """
 
     def setUp(self):
-        super(CommonLoggerTestsMixIn, self).setUp()
+        super().setUp()
         # common context has different fields to the defaults in log.py
         self.config_fixture = self.useFixture(
             fixture_config.Config(cfg.ConfigOpts()))
@@ -135,43 +132,6 @@ class CommonLoggerTestsMixIn(object):
                      'info', 'debug', 'log'):
             self.assertRaises(AttributeError, getattr, log, func)
 
-    @mock.patch('platform.system', return_value='Linux')
-    def test_eventlog_missing(self, platform_mock):
-        self.config(use_eventlog=True)
-        self.assertRaises(RuntimeError,
-                          log._setup_logging_from_conf,
-                          self.CONF,
-                          'test',
-                          'test')
-
-    @mock.patch('platform.system', return_value='Windows')
-    @mock.patch('logging.handlers.NTEventLogHandler')
-    @mock.patch('oslo_log.log.getLogger')
-    def test_eventlog(self, loggers_mock, handler_mock, platform_mock):
-        self.config(use_eventlog=True)
-        log._setup_logging_from_conf(self.CONF, 'test', 'test')
-        handler_mock.assert_called_once_with('test')
-        mock_logger = loggers_mock.return_value.logger
-        mock_logger.addHandler.assert_any_call(handler_mock.return_value)
-
-    @mock.patch('oslo_log.watchers.FastWatchedFileHandler')
-    @mock.patch('oslo_log.log._get_log_file_path', return_value='test.conf')
-    @mock.patch('platform.system', return_value='Linux')
-    def test_watchlog_on_linux(self, platfotm_mock, path_mock, handler_mock):
-        self.config(watch_log_file=True)
-        log._setup_logging_from_conf(self.CONF, 'test', 'test')
-        handler_mock.assert_called_once_with(path_mock.return_value)
-        self.assertEqual(self.log_handlers[0], handler_mock.return_value)
-
-    @mock.patch('logging.handlers.WatchedFileHandler')
-    @mock.patch('oslo_log.log._get_log_file_path', return_value='test.conf')
-    @mock.patch('platform.system', return_value='Windows')
-    def test_watchlog_on_windows(self, platform_mock, path_mock, handler_mock):
-        self.config(watch_log_file=True)
-        log._setup_logging_from_conf(self.CONF, 'test', 'test')
-        handler_mock.assert_called_once_with(path_mock.return_value)
-        self.assertEqual(self.log_handlers[0], handler_mock.return_value)
-
     @mock.patch('logging.handlers.TimedRotatingFileHandler')
     @mock.patch('oslo_log.log._get_log_file_path', return_value='test.conf')
     def test_timed_rotate_log(self, path_mock, handler_mock):
@@ -209,13 +169,13 @@ class CommonLoggerTestsMixIn(object):
 
 class LoggerTestCase(CommonLoggerTestsMixIn, test_base.BaseTestCase):
     def setUp(self):
-        super(LoggerTestCase, self).setUp()
+        super().setUp()
         self.log = log.getLogger(None)
 
 
 class BaseTestCase(test_base.BaseTestCase):
     def setUp(self):
-        super(BaseTestCase, self).setUp()
+        super().setUp()
         self.context_fixture = self.useFixture(
             fixture_context.ClearRequestContext())
         self.config_fixture = self.useFixture(
@@ -313,7 +273,7 @@ class LogHandlerTestCase(BaseTestCase):
 class SysLogHandlersTestCase(BaseTestCase):
     """Test the standard Syslog handler."""
     def setUp(self):
-        super(SysLogHandlersTestCase, self).setUp()
+        super().setUp()
         self.facility = logging.handlers.SysLogHandler.LOG_USER
         self.logger = logging.handlers.SysLogHandler(facility=self.facility)
 
@@ -356,7 +316,7 @@ class OSSysLogHandlerTestCase(BaseTestCase):
                           "fougere")
 
     def test_syslog(self):
-        msg_unicode = u"Benoît Knecht & François Deppierraz login failure"
+        msg_unicode = "Benoît Knecht & François Deppierraz login failure"
         handler = handlers.OSSysLogHandler()
         syslog.syslog = mock.Mock()
         handler.emit(
@@ -377,7 +337,7 @@ class OSJournalHandlerTestCase(BaseTestCase):
 
     """
     def setUp(self):
-        super(OSJournalHandlerTestCase, self).setUp()
+        super().setUp()
         self.config(use_journal=True)
         self.journal = mock.patch("oslo_log.handlers.journal").start()
         self.addCleanup(self.journal.stop)
@@ -457,7 +417,7 @@ class OSJournalHandlerTestCase(BaseTestCase):
 
 class LogLevelTestCase(BaseTestCase):
     def setUp(self):
-        super(LogLevelTestCase, self).setUp()
+        super().setUp()
         levels = self.CONF.default_log_levels
         info_level = 'nova-test'
         warn_level = 'nova-not-debug'
@@ -503,7 +463,7 @@ class LogLevelTestCase(BaseTestCase):
 
 class JSONFormatterTestCase(LogTestBase):
     def setUp(self):
-        super(JSONFormatterTestCase, self).setUp()
+        super().setUp()
         self.log = log.getLogger('test-json')
         self._add_handler_with_cleanup(self.log,
                                        formatter=formatters.JSONFormatter)
@@ -615,12 +575,12 @@ class JSONFormatterTestCase(LogTestBase):
         expected = b'\\u2622'
         # see ContextFormatterTestCase.test_can_process_strings
         expected = '\\\\xe2\\\\x98\\\\xa2'
-        self.log.info(b'%s', '\u2622'.encode('utf8'))
+        self.log.info(b'%s', '\u2622'.encode())
         self.assertIn(expected, self.stream.getvalue())
 
     def test_exception(self):
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         try:
             raise RuntimeError('test_exception')
         except RuntimeError:
@@ -632,7 +592,7 @@ class JSONFormatterTestCase(LogTestBase):
 
     def test_no_exception(self):
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         self.log.info('testing', context=ctxt)
         data = jsonutils.loads(self.stream.getvalue())
         self.assertIn('error_summary', data)
@@ -640,7 +600,7 @@ class JSONFormatterTestCase(LogTestBase):
 
     def test_exception_without_exc_info_passed(self):
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         try:
             raise RuntimeError('test_exception\ntraceback\nfrom\nremote error')
         except RuntimeError:
@@ -651,7 +611,7 @@ class JSONFormatterTestCase(LogTestBase):
 
     def test_exception_with_exc_info_passed(self):
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         try:
             raise RuntimeError('test_exception\ntraceback\nfrom\nremote error')
         except RuntimeError:
@@ -664,7 +624,7 @@ class JSONFormatterTestCase(LogTestBase):
 
     def test_fallback(self):
 
-        class MyObject(object):
+        class MyObject:
             def __str__(self):
                 return 'str'
 
@@ -721,7 +681,7 @@ class DictStreamHandler(logging.StreamHandler):
 
 class FluentFormatterTestCase(LogTestBase):
     def setUp(self):
-        super(FluentFormatterTestCase, self).setUp()
+        super().setUp()
         self.log = log.getLogger('test-fluent')
         self._add_handler_with_cleanup(self.log,
                                        handler=DictStreamHandler,
@@ -796,7 +756,7 @@ class FluentFormatterTestCase(LogTestBase):
 
 class ContextFormatterTestCase(LogTestBase):
     def setUp(self):
-        super(ContextFormatterTestCase, self).setUp()
+        super().setUp()
         self.config(logging_context_format_string="HAS CONTEXT "
                                                   "[%(request_id)s]: "
                                                   "%(message)s",
@@ -816,14 +776,14 @@ class ContextFormatterTestCase(LogTestBase):
         ctxt = _fake_context()
         message = 'bar'
         self.log.info(message, context=ctxt)
-        expected = 'HAS CONTEXT [%s]: %s\n' % (ctxt.request_id, message)
+        expected = 'HAS CONTEXT [{}]: {}\n'.format(ctxt.request_id, message)
         self.assertEqual(expected, self.stream.getvalue())
 
     def test_context_is_taken_from_tls_variable(self):
         ctxt = _fake_context()
         message = 'bar'
         self.log.info(message)
-        expected = "HAS CONTEXT [%s]: %s\n" % (ctxt.request_id, message)
+        expected = "HAS CONTEXT [{}]: {}\n".format(ctxt.request_id, message)
         self.assertEqual(expected, self.stream.getvalue())
 
     def test_contextual_information_is_imparted_to_3rd_party_log_records(self):
@@ -833,19 +793,19 @@ class ContextFormatterTestCase(LogTestBase):
         message = 'emulate logging within sqlalchemy'
         sa_log.info(message)
 
-        expected = ('HAS CONTEXT [%s]: %s\n' % (ctxt.request_id, message))
+        expected = ('HAS CONTEXT [{}]: {}\n'.format(ctxt.request_id, message))
         self.assertEqual(expected, self.stream.getvalue())
 
     def test_message_logging_3rd_party_log_records(self):
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         sa_log = logging.getLogger('sqlalchemy.engine')
         sa_log.setLevel(logging.INFO)
         message = self.trans_fixture.lazy('test ' + chr(128))
         sa_log.info(message)
 
-        expected = ('HAS CONTEXT [%s]: %s\n' % (ctxt.request_id,
-                                                str(message)))
+        expected = ('HAS CONTEXT [{}]: {}\n'.format(ctxt.request_id,
+                                                    str(message)))
         self.assertEqual(expected, self.stream.getvalue())
 
     def test_debugging_log(self):
@@ -860,11 +820,11 @@ class ContextFormatterTestCase(LogTestBase):
         # the Message object, with a wrong encoding. This test case
         # tests that problem does not occur.
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         message = self.trans_fixture.lazy('test ' + chr(128))
         self.log.info(message, context=ctxt)
-        expected = "HAS CONTEXT [%s]: %s\n" % (ctxt.request_id,
-                                               str(message))
+        expected = "HAS CONTEXT [{}]: {}\n".format(ctxt.request_id,
+                                                   str(message))
         self.assertEqual(expected, self.stream.getvalue())
 
     def test_exception_logging(self):
@@ -872,7 +832,7 @@ class ContextFormatterTestCase(LogTestBase):
         # does not appear in the format string, ensure that it is
         # appended to the end of the log lines.
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         message = self.trans_fixture.lazy('test ' + chr(128))
         try:
             raise RuntimeError('test_exception_logging')
@@ -885,7 +845,7 @@ class ContextFormatterTestCase(LogTestBase):
         # NOTE(dhellmann): Several of the built-in exception types
         # should not be automatically added to the log output.
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         message = self.trans_fixture.lazy('test ' + chr(128))
         ignored_exceptions = [
             ValueError, TypeError, KeyError, AttributeError, ImportError
@@ -904,7 +864,7 @@ class ContextFormatterTestCase(LogTestBase):
         # that position in the output.
         self.config(logging_context_format_string="A %(error_summary)s B")
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         message = self.trans_fixture.lazy('test ' + chr(128))
         try:
             raise RuntimeError('test_exception_logging')
@@ -919,7 +879,7 @@ class ContextFormatterTestCase(LogTestBase):
         # inserted.
         self.config(logging_context_format_string="%(error_summary)s")
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         message = self.trans_fixture.lazy('test ' + chr(128))
         self.log.info(message, context=ctxt)
         expected = '-\n'
@@ -927,26 +887,26 @@ class ContextFormatterTestCase(LogTestBase):
 
     def test_unicode_conversion_in_adapter(self):
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         message = "Exception is (%s)"
         ex = Exception(self.trans_fixture.lazy('test' + chr(128)))
         self.log.debug(message, ex, context=ctxt)
         message = str(message) % ex
-        expected = "HAS CONTEXT [%s]: %s --DBG\n" % (ctxt.request_id,
-                                                     message)
+        expected = "HAS CONTEXT [{}]: {} --DBG\n".format(ctxt.request_id,
+                                                         message)
         self.assertEqual(expected, self.stream.getvalue())
 
     def test_unicode_conversion_in_formatter(self):
         ctxt = _fake_context()
-        ctxt.request_id = str('99')
+        ctxt.request_id = '99'
         no_adapt_log = logging.getLogger('no_adapt')
         no_adapt_log.setLevel(logging.INFO)
         message = "Exception is (%s)"
         ex = Exception(self.trans_fixture.lazy('test' + chr(128)))
         no_adapt_log.info(message, ex)
         message = str(message) % ex
-        expected = "HAS CONTEXT [%s]: %s\n" % (ctxt.request_id,
-                                               message)
+        expected = "HAS CONTEXT [{}]: {}\n".format(ctxt.request_id,
+                                                   message)
         self.assertEqual(expected, self.stream.getvalue())
 
     def test_user_identity_logging(self):
@@ -959,11 +919,24 @@ class ContextFormatterTestCase(LogTestBase):
         message = 'test'
         self.log.info(message, context=ctxt)
         expected = ("HAS CONTEXT [%s %s %s %s %s %s %s]: %s\n" %
-                    (ctxt.request_id, ctxt.user, ctxt.project_id, ctxt.domain,
-                     ctxt.system_scope, ctxt.user_domain, ctxt.project_domain,
+                    (ctxt.request_id, ctxt.user_id, ctxt.project_id,
+                     ctxt.domain_id, ctxt.system_scope,
+                     ctxt.user_domain_id, ctxt.project_domain_id,
                      str(message)))
         self.assertEqual(expected, self.stream.getvalue())
 
+    def test_global_request_id_logging(self):
+        fmt_str = "HAS CONTEXT [%(request_id)s %(global_request_id)s]: " \
+                  "%(message)s"
+        self.config(logging_context_format_string=fmt_str)
+        ctxt = _fake_context()
+        ctxt.request_id = '99'
+        message = 'test'
+        self.log.info(message, context=ctxt)
+        expected = ("HAS CONTEXT [%s %s]: %s\n" %
+                    (ctxt.request_id, ctxt.global_request_id, str(message)))
+        self.assertEqual(expected, self.stream.getvalue())
+
     def test_user_identity_logging_set_format(self):
         self.config(logging_context_format_string="HAS CONTEXT "
                                                   "[%(request_id)s "
@@ -976,7 +949,7 @@ class ContextFormatterTestCase(LogTestBase):
         message = 'test'
         self.log.info(message, context=ctxt)
         expected = ("HAS CONTEXT [%s %s %s]: %s\n" %
-                    (ctxt.request_id, ctxt.user, ctxt.project_id,
+                    (ctxt.request_id, ctxt.user_id, ctxt.project_id,
                      str(message)))
         self.assertEqual(expected, self.stream.getvalue())
 
@@ -998,6 +971,8 @@ class ContextFormatterTestCase(LogTestBase):
                 get_fake_datetime(
                     datetime.datetime(2015, 12, 16, 13, 54, 26)))
     @mock.patch("time.time", new=mock.Mock(return_value=1450274066.000000))
+    @mock.patch("time.time_ns",
+                new=mock.Mock(return_value=1450274066000000000))
     @mock.patch("dateutil.tz.tzlocal", new=mock.Mock(return_value=tz.tzutc()))
     def test_rfc5424_isotime_format_no_microseconds(self):
         self.config(logging_default_format_string="%(isotime)s %(message)s")
@@ -1015,7 +990,7 @@ class ContextFormatterTestCase(LogTestBase):
         # or it will fail and inserting byte string in unicode string
         # causes such formatting
         expected = '\\xe2\\x98\\xa2'
-        self.log.info(b'%s', '\u2622'.encode('utf8'))
+        self.log.info(b'%s', '\u2622'.encode())
         self.assertIn(expected, self.stream.getvalue())
 
     def test_dict_args_with_unicode(self):
@@ -1083,7 +1058,7 @@ class FancyRecordTestCase(LogTestBase):
     """
 
     def setUp(self):
-        super(FancyRecordTestCase, self).setUp()
+        super().setUp()
         # NOTE(sdague): use the different formatters to demonstrate format
         # string with valid fancy keys and without. Slightly hacky, but given
         # the way log objects layer up seemed to be most concise approach
@@ -1115,14 +1090,14 @@ class FancyRecordTestCase(LogTestBase):
         warncolor = handlers.ColorHandler.LEVEL_COLORS[logging.WARN]
         info_msg = 'info'
         warn_msg = 'warn'
-        infoexpected = "%s %s %s" % (infocolor, keyed_log_string, info_msg)
-        warnexpected = "%s %s %s" % (warncolor, keyed_log_string, warn_msg)
+        infoexpected = "{} {} {}".format(infocolor, keyed_log_string, info_msg)
+        warnexpected = "{} {} {}".format(warncolor, keyed_log_string, warn_msg)
 
         self.colorlog.info(info_msg, context=ctxt)
         self.assertIn(infoexpected, self.stream.getvalue())
         self.assertEqual('\033[00;36m', infocolor)
 
-        self.colorlog.warn(warn_msg, context=ctxt)
+        self.colorlog.warning(warn_msg, context=ctxt)
         self.assertIn(infoexpected, self.stream.getvalue())
         self.assertIn(warnexpected, self.stream.getvalue())
         self.assertEqual('\033[01;33m', warncolor)
@@ -1164,7 +1139,7 @@ class FancyRecordTestCase(LogTestBase):
 
 class InstanceRecordTestCase(LogTestBase):
     def setUp(self):
-        super(InstanceRecordTestCase, self).setUp()
+        super().setUp()
         self.config(logging_context_format_string="[%(request_id)s]: "
                                                   "%(instance)s"
                                                   "%(resource)s"
@@ -1237,7 +1212,7 @@ class InstanceRecordTestCase(LogTestBase):
 
 class TraceLevelTestCase(LogTestBase):
     def setUp(self):
-        super(TraceLevelTestCase, self).setUp()
+        super().setUp()
         self.config(logging_context_format_string="%(message)s")
         self.mylog = log.getLogger()
         self._add_handler_with_cleanup(self.mylog)
@@ -1252,7 +1227,7 @@ class TraceLevelTestCase(LogTestBase):
 
 class DomainTestCase(LogTestBase):
     def setUp(self):
-        super(DomainTestCase, self).setUp()
+        super().setUp()
         self.config(logging_context_format_string="[%(request_id)s]: "
                                                   "%(user_identity)s "
                                                   "%(message)s",
@@ -1266,23 +1241,23 @@ class DomainTestCase(LogTestBase):
 
     def _validate_keys(self, ctxt, keyed_log_string):
         info_message = 'info'
-        infoexpected = "%s %s\n" % (keyed_log_string, info_message)
+        infoexpected = "{} {}\n".format(keyed_log_string, info_message)
         warn_message = 'warn'
-        warnexpected = "%s %s\n" % (keyed_log_string, warn_message)
+        warnexpected = "{} {}\n".format(keyed_log_string, warn_message)
 
         self.mylog.info(info_message, context=ctxt)
         self.assertEqual(infoexpected, self.stream.getvalue())
 
-        self.mylog.warn(warn_message, context=ctxt)
+        self.mylog.warning(warn_message, context=ctxt)
         self.assertEqual(infoexpected + warnexpected, self.stream.getvalue())
 
     def test_domain_in_log_msg(self):
         ctxt = _fake_context()
         user_identity = (self.CONF.logging_user_identity_format %
                          ctxt.get_logging_values())
-        self.assertIn(ctxt.domain, user_identity)
-        self.assertIn(ctxt.project_domain, user_identity)
-        self.assertIn(ctxt.user_domain, user_identity)
+        self.assertIn(ctxt.domain_id, user_identity)
+        self.assertIn(ctxt.project_domain_id, user_identity)
+        self.assertIn(ctxt.user_domain_id, user_identity)
         self._validate_keys(ctxt, ('[%s]: %s' %
                                    (ctxt.request_id, user_identity)))
 
@@ -1298,13 +1273,13 @@ class SetDefaultsTestCase(BaseTestCase):
                                            default_config_files=[])
 
     def setUp(self):
-        super(SetDefaultsTestCase, self).setUp()
+        super().setUp()
         self.conf = self.TestConfigOpts()
         self.conf.register_opts(_options.log_opts)
         self.conf.register_cli_opts(_options.logging_cli_opts)
 
-        self._orig_defaults = dict([(o.dest, o.default)
-                                    for o in _options.log_opts])
+        self._orig_defaults = {o.dest: o.default
+                               for o in _options.log_opts}
         self.addCleanup(self._restore_log_defaults)
 
     def _restore_log_defaults(self):
@@ -1351,57 +1326,9 @@ class SetDefaultsTestCase(BaseTestCase):
         self.assertIsNone(self.conf.log_file)
 
 
-@testtools.skipIf(platform.system() != 'Linux',
-                  'pyinotify library works on Linux platform only.')
-class FastWatchedFileHandlerTestCase(BaseTestCase):
-
-    def setUp(self):
-        super(FastWatchedFileHandlerTestCase, self).setUp()
-
-    def _config(self):
-        os_level, log_path = tempfile.mkstemp()
-        log_dir_path = os.path.dirname(log_path)
-        log_file_path = os.path.basename(log_path)
-        self.CONF(['--log-dir', log_dir_path, '--log-file', log_file_path])
-        self.config(use_stderr=False)
-        self.config(watch_log_file=True)
-        log.setup(self.CONF, 'test', 'test')
-        return log_path
-
-    def test_instantiate(self):
-        self._config()
-        logger = log._loggers[None].logger
-        self.assertEqual(1, len(logger.handlers))
-        from oslo_log import watchers
-        self.assertIsInstance(logger.handlers[0],
-                              watchers.FastWatchedFileHandler)
-
-    def test_log(self):
-        log_path = self._config()
-        logger = log._loggers[None].logger
-        text = 'Hello World!'
-        logger.info(text)
-        with open(log_path, 'r') as f:
-            file_content = f.read()
-        self.assertIn(text, file_content)
-
-    def test_move(self):
-        log_path = self._config()
-        os_level_dst, log_path_dst = tempfile.mkstemp()
-        os.rename(log_path, log_path_dst)
-        time.sleep(6)
-        self.assertTrue(os.path.exists(log_path))
-
-    def test_remove(self):
-        log_path = self._config()
-        os.remove(log_path)
-        time.sleep(6)
-        self.assertTrue(os.path.exists(log_path))
-
-
 class MutateTestCase(BaseTestCase):
     def setUp(self):
-        super(MutateTestCase, self).setUp()
+        super().setUp()
         if hasattr(log._load_log_config, 'old_time'):
             del log._load_log_config.old_time
 
@@ -1497,9 +1424,9 @@ class MutateTestCase(BaseTestCase):
                           "keys=%s" % skeys])
             for key in keys:
                 lines.extend(["",
-                              "[%s_%s]" % (section[:-1], key)])
+                              "[{}_{}]".format(section[:-1], key)])
                 item = items[key]
-                lines.extend("%s=%s" % (k, item[k]) for k in sorted(item))
+                lines.extend("{}={}".format(k, item[k]) for k in sorted(item))
                 if section == 'handlers':
                     if 'args' not in item:
                         lines.append("args=()")
@@ -1511,7 +1438,7 @@ class MutateTestCase(BaseTestCase):
         root = data.get('root', {})
         if root:
             lines.extend(["[logger_root]"])
-            lines.extend("%s=%s" % (k, root[k]) for k in sorted(root))
+            lines.extend("{}={}".format(k, root[k]) for k in sorted(root))
             if 'handlers' not in root:
                 lines.append("handlers=")
         return "\n".join(lines)
@@ -1645,18 +1572,18 @@ keys=
             stream = self.set_root_stream()
             log = logging.getLogger("a.a")
             log.info("info")
-            log.warn("warn")
+            log.warning("warn")
             self.assertEqual("warn\n", stream.getvalue())
         stream = self.set_root_stream()
         log.info("info")
-        log.warn("warn")
+        log.warning("warn")
         self.assertEqual("info\nwarn\n", stream.getvalue())
 
 
 class LogConfigOptsTestCase(BaseTestCase):
 
     def setUp(self):
-        super(LogConfigOptsTestCase, self).setUp()
+        super().setUp()
 
     def test_print_help(self):
         f = io.StringIO()
@@ -1770,7 +1697,7 @@ class LogConfigOptsTestCase(BaseTestCase):
 
 class LogConfigTestCase(BaseTestCase):
     def setUp(self):
-        super(LogConfigTestCase, self).setUp()
+        super().setUp()
         names = self.create_tempfiles([('logging', MIN_LOG_INI)])
         self.log_config_append = names[0]
         if hasattr(log._load_log_config, 'old_time'):
@@ -1820,7 +1747,7 @@ class SavingAdapter(log.KeywordArgumentAdapter):
     def process(self, msg, kwargs):
         # Run the real adapter and save the inputs and outputs
         # before returning them so the test can examine both.
-        results = super(SavingAdapter, self).process(msg, kwargs)
+        results = super().process(msg, kwargs)
         self.results.append((msg, kwargs, results))
         return results
 
@@ -1828,7 +1755,7 @@ class SavingAdapter(log.KeywordArgumentAdapter):
 class KeywordArgumentAdapterTestCase(BaseTestCase):
 
     def setUp(self):
-        super(KeywordArgumentAdapterTestCase, self).setUp()
+        super().setUp()
         # Construct a mock that will look like a Logger configured to
         # emit messages at DEBUG or higher.
         self.mock_log = mock.Mock()
@@ -1958,7 +1885,7 @@ class LoggerNameTestCase(LoggerTestCase):
 
 class IsDebugEnabledTestCase(test_base.BaseTestCase):
     def setUp(self):
-        super(IsDebugEnabledTestCase, self).setUp()
+        super().setUp()
         self.config_fixture = self.useFixture(
             fixture_config.Config(cfg.ConfigOpts()))
         self.config = self.config_fixture.config
